@@ -1,4 +1,4 @@
-"""
+'''
 # Create and Publish CDK Constructs Using projen and jsii
 
 This project tests and describes the workflow of creating an [AWS CDK](https://aws.amazon.com/cdk/) construct using [projen](https://github.com/projen/projen) + [jsii](https://github.com/aws/jsii) and publishing it to various repositories like npm, Maven Central, PyPi and NuGet.
@@ -97,8 +97,8 @@ In case you want to test `projen` as well, here are the steps I've performed.
    * optional: explicitly add `docgen: true` so it automatically generates API documentation 🙌
    * optional: explicitly add `eslint: true` to make sure you use common coding standards
    * optional: add `dependabot: true` and `dependabotOptions: {...}` to enable [Dependabot](https://dependabot.com/) if you hate manually managing dependency updates
-   * optional: add `gitignore: ['.idea']` if you love using IntelliJ ♥️ but don't want to commit its settings
-   * optional: use `packageManager: NodePackageManager.NPM` if you want to use npm instead of Yarn - might be important in case you are migrating an existing CDK Construct to `projen`.
+   * optional: add `gitignore: ['.idea']` if you love using IntelliJ ♥️ but don't want to commit its settings - or if you want to ignore any other files :)
+   * optional: use `packageManager: NodePackageManager.NPM` if you want to use `npm` instead of `yarn` - might be important in case you are migrating an existing CDK Construct to `projen`.
 
    Don't forget to add necessary imports in the config file when applying the `projen` settings, e.g. for using `ProjectType` or `NodePackageManager`.
 5. Set a version number in [version.json](version.json), e.g. `0.0.1`.
@@ -161,6 +161,8 @@ git push -u origin main
 
 ### Publishing to Different Repositories
 
+![successful-projen-action-run](assets/successful-projen-action-run.png)
+
 If you want to release your package to one or multiple repositories like npm or Maven Central, you'll have to enable this in [.projenrc.js](.projenrc.js).
 After changing the configuration as described below and calling `pj` (or `npx projen` if you're not using the alias), you'll notice that there are a few files in [.github/workflows](.github/workflows) folder.
 They take care of running [GitHub Actions](https://github.com/features/actions) to build and release/publish the library to npm and other repositories.
@@ -266,7 +268,7 @@ In order to publish to [PyPi](https://pypi.org/), you need an account there.
 
 Have a look at the published package: [projen-test](https://pypi.org/project/projen-test/)
 
-### Publish to NuGet
+#### Publish to NuGet
 
 1. Update [.projenrc.js](.projenrc.js) configuration:
 
@@ -389,7 +391,7 @@ In order to figure out the `MAVEN_STAGING_PROFILE_ID`, follow these steps:
 * In the main window, make sure you select the tab `Staging Profiles` and select the entry matching your namespace `org.example`
 * You'll notice the URL has changed to `https://oss.sonatype.org/#stagingProfiles;12abc3456789`
 * Use the id after the `;` semicolon as the `MAVEN_STAGING_PROFILE_ID`
-"""
+'''
 import abc
 import builtins
 import datetime
@@ -410,13 +412,13 @@ class InlineLambdaConstruct(
     metaclass=jsii.JSIIMeta,
     jsii_type="@seeebiii/projen-test.InlineLambdaConstruct",
 ):
-    """A simple CDK construct to create a Lambda function with static inline code that prints the event and calls the callback function."""
+    '''A simple CDK construct to create a Lambda function with static inline code that prints the event and calls the callback function.'''
 
     def __init__(self, parent: aws_cdk.core.Construct, name: builtins.str) -> None:
-        """
+        '''
         :param parent: -
         :param name: -
-        """
+        '''
         jsii.create(InlineLambdaConstruct, self, [parent, name])
 
 
